@@ -10,6 +10,6 @@ gulp.task('scripts', function () {
     return gulp.src('lib/gettext.js')
         .pipe(gulp.dest('dist'))
         .pipe(rename({ suffix: '.min' }))
-        .pipe(uglify({ preserveComments: 'some' }))
+        .pipe(uglify({output: { comments: 'some' }}))
         .pipe(gulp.dest('dist'));
 });
