@@ -7,7 +7,7 @@
     // default values that could be overriden in i18n() construct
     var defaults = {
       domain: 'messages',
-      locale: (document ? document.documentElement.getAttribute('lang') : false) || 'en',
+      locale: (typeof document !== 'undefined' ? document.documentElement.getAttribute('lang') : false) || 'en',
       plural_func: function (n) { return { nplurals: 2, plural: (n!=1) ? 1 : 0 }; },
       ctxt_delimiter: String.fromCharCode(4) // \u0004
     };
@@ -46,9 +46,26 @@
       var strfmt = function (fmt) {
         var args = arguments;
 
-        return fmt.replace(/%(\d+)/g, function (str, p1) {
-          return args[p1];
-        });
+        return fmt
+          // put space after double % to prevent placeholder replacement of such matches
+          .replace(/%%/g, '%% ')
+          // replace placeholders
+          .replace(/%(\d+)/g, function (str, p1) {
+            return args[p1];
+          })
+          // replace double % and space with single %
+          .replace(/%% /g, '%')
+      };
+
+      var expand_locale = function(locale) {
+          var locales = [locale],
+              i = locale.lastIndexOf('-');
+          while (i > 0) {
+              locale = locale.slice(0, i);
+              locales.push(locale);
+              i = locale.lastIndexOf('-');
+          }
+          return locales;
       };
 
       var getPluralFunc = function (plural_form) {
@@ -99,6 +116,7 @@
 
     return {
       strfmt: strfmt, // expose strfmt util
+      expand_locale: expand_locale, // expose expand_locale util
 
       // Declare shortcuts
       __: function () { return this.gettext.apply(this, arguments); },
@@ -167,22 +185,31 @@
           translation,
           options = {},
           key = msgctxt ? msgctxt + _ctxt_delimiter + msgid : msgid,
-          exist = _dictionary[domain] && _dictionary[domain][_locale] && _dictionary[domain][_locale][key];
+          exist,
+          locale;
+        var locales = expand_locale(_locale);
+        for (var i in locales) {
+            locale = locales[i];
+            exist = _dictionary[domain] && _dictionary[domain][locale] && _dictionary[domain][locale][key];
 
-        // because it's not possible to define both a singular and a plural form of the same msgid,
-        // we need to check that the stored form is the same as the expected one.
-        // if not, we'll just ignore the translation and consider it as not translated.
-        if (msgid_plural) {
-          exist = exist && "string" !== typeof _dictionary[domain][_locale][key];
-        } else {
-          exist = exist && "string" === typeof _dictionary[domain][_locale][key];
+            // because it's not possible to define both a singular and a plural form of the same msgid,
+            // we need to check that the stored form is the same as the expected one.
+            // if not, we'll just ignore the translation and consider it as not translated.
+            if (msgid_plural) {
+              exist = exist && "string" !== typeof _dictionary[domain][locale][key];
+            } else {
+              exist = exist && "string" === typeof _dictionary[domain][locale][key];
+            }
+            if (exist) {
+                break;
+            }
         }
 
         if (!exist) {
           translation = msgid;
           options.plural_func = defaults.plural_func;
         } else {
-          translation = _dictionary[domain][_locale][key];
+          translation = _dictionary[domain][locale][key];
         }
 
         // Singular form
